import { register } from "@antv/x6-react-shape";
import { Node } from "@antv/x6";
import { defaultData } from "@/components/data";
import { useSizeHook, useShapeProps } from "@/hooks";
import CustomInput from "../CustomInput";
const component = ({ node }: { node: Node }) => {
  const { fill, stroke, opacity, label, text, borderSize } = node.getData();
  const { size, ref } = useSizeHook();
  const {
    fillContent,
    strokeColor,
    strokeWidth,
    strokeDasharray,
  } = useShapeProps(fill, size, stroke);

  return (
    <>
      <div
        className="relative text-0 w-full h-full"
        ref={ref}
        style={{ 
          opacity: opacity / 100,
          border: `solid ${strokeWidth}px ${strokeColor}`,
          background: fillContent,
          borderRadius: borderSize
        }}
      >
       <CustomInput value={label} node={node} styles={text} />
      </div>
    </>
  );
};

register({
  shape: "mind-map-topic",
  width: 206,
  height: 70,
  effect: ["data"],
  component: component,
});

const baseNode = {
  shape: "mind-map-topic",
  data: {
    label: "",
    ...defaultData,
  },
};

export default baseNode;
